@@ -1,7 +1,7 @@
-/* Copyright (C) 2006 Brice Arnould.
+/* Copyright (C) 2006-2008 Brice Arnould.
  *  This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  *  This program is distributed in the hope that it will be useful,
@@ -10,10 +10,12 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ *
  */
 #include <stdio.h>		// puts(), printf(), putchar()
+
+#include "config.h"
 #include "msg.h"
 
 void
@@ -53,7 +55,7 @@ show_version (void)
 {
   puts ("\
 Shake " VERSION "\n\
-Copyright (C) 2006 Brice Arnould.\n\
+Copyright (C) 2006-2008 Brice Arnould.\n\
 Shake comes with ABSOLUTELY NO WARRANTY. You may redistribute copies of Shake\n\
 under the terms of the GNU General Public License. For more information about\n\
 these matters, see the file named GPL.txt.\
